﻿/// <reference path="./jimu.d.ts" />
/// <reference path="./arcgis-js-api.d.ts" />

import BaseWidget = require("jimu/BaseWidget");
import Map = require("esri/map");
import SOEClient = require("./SOEClient");

class WidgetHelper
{

	baseClass: string = "jimu-widget-electrictracewidget";

	createWidgetProps(): any
	{
		var props: any = {};
		props["baseClass"] = this.baseClass;
		props["intWidgetHelper"] = this;  
		// In the startup function context, "this" is the actual widget
		props["startup"] = function () { this.intWidgetHelper.initialize(this); }  
		// The remaining functions use lambda expressions so that "this" is the WidgetHelper instance
		props["_onProcessIdClick"] = () => { this.getProcessId(); }
		props["_onTraceClick"] = () => { this.activateTool(); }
		props["_onClearClick"] = () => { this.clearResults(); }
		return props;
	}

	private _bw: BaseWidget; // Use this to make BaseWidget calls
	private _map: Map;
	private _spStatus: HTMLElement;
	private _client: SOEClient;

	initialize(widget: any): void
	{

		// Set up SOEClient

		this._bw = widget;
		this._map = this._bw.map;
		this._spStatus = widget.spStatus;
		this._client = new SOEClient();
		this._client.startClient(this._map, this._spStatus);

		// Populate button images

		var IDList: Array<string> =
			[
				"btnQuery",
				"btnTraceOut",
				"btnClear"
			];
		for (var i in IDList)
		{
			var sID: string = IDList[i];
			var sPath: string = this._bw.folderUrl + "images/" + sID + ".png";
			var img: HTMLElement = document.getElementById(sID);
			img.setAttribute("src", sPath);
			var btn: HTMLButtonElement;
		}

	}

	getProcessId(): void
	{
		this._client.getProcessId();
	}

	activateTool(): void
	{
		this._client.activateTool();
	}

	clearResults(): void
	{
		this._client.clearResults();
	}

}
export = WidgetHelper;
 