/// <reference path="./jimu.d.ts" />
/// <reference path="./arcgis-js-api.d.ts" />
/// <reference path="./dojox.charting.d.ts" />
define(["require", "exports", "esri/tasks/StatisticDefinition", "esri/tasks/query", "esri/tasks/QueryTask", "dojox/charting/Chart", "dojox/charting/plot2d/Pie", "dojox/charting/SimpleTheme", "dojox/charting/action2d/Highlight", "dojox/charting/action2d/Tooltip"], function (require, exports, StatisticDefinition, Query, QueryTask, Chart, PiePlot, SimpleTheme, Highlight, Tooltip) {
    var WidgetHelper = (function () {
        function WidgetHelper() {
            this.baseClass = "jimu-widget-layerpiechart";
            this.outStatisticField = "MY_STATISTIC";
        }
        WidgetHelper.prototype.createWidgetProps = function () {
            var props = {};
            props["baseClass"] = this.baseClass;
            props["intWidgetHelper"] = this;
            // In the startup function context, "this" is the actual widget
            props["startup"] = function () { this.intWidgetHelper.initialize(this); };
            // The remaining functions use lambda expressions so that "this" is the WidgetHelper instance
            //props["onOpen"] = () => { this.onOpen(); }
            //props["onClose"] = () => { this.onClose(); }
            return props;
        };
        WidgetHelper.prototype.initialize = function (widget) {
            // Initialize members
            var _this = this;
            this._bw = widget;
            this._divChart = widget.divChart;
            this._sUrl = this._bw.config.layerUrl;
            this._sStatisticType = this._bw.config.statisticType;
            this._sStatisticField = this._bw.config.onStatisticField;
            this._sGroupByField = this._bw.config.groupByField;
            this._GroupByLabels = this._bw.config.groupByLabels;
            this._Values = this._bw.config.values;
            this._Colors = this._bw.config.colors;
            this._Statistics = {};
            // Query service for statistics for pie chart
            var sd = new StatisticDefinition();
            sd.statisticType = this._sStatisticType;
            sd.onStatisticField = this._sStatisticField;
            sd.outStatisticFieldName = this.outStatisticField;
            var q = new Query();
            q.returnGeometry = false;
            q.outStatistics = [sd];
            q.groupByFieldsForStatistics = [this._sGroupByField];
            var qt = new QueryTask(this._sUrl);
            qt.on("complete", function (evt) { _this.getStatistics(evt); });
            qt.on("error", function (evt) { window.alert("ERROR: " + evt.error.message); });
            qt.execute(q);
        };
        WidgetHelper.prototype.getStatistics = function (evt) {
            // Collate statistics
            var featureSet = evt.featureSet;
            var Features = featureSet.features;
            var iCount = Features.length;
            for (var i = 0; i < iCount; i++) {
                var gr = Features[i];
                var attr = gr.attributes;
                var val = attr[this._sGroupByField];
                var dVal = attr[this.outStatisticField];
                // Find label that goes with value
                var sLabel = null;
                for (var j = 0; j < this._GroupByLabels.length; j++) {
                    var sKey = this._GroupByLabels[j];
                    var v = this._Values[sKey];
                    if (v == val) {
                        sLabel = sKey;
                        break;
                    }
                }
                if (sLabel == null)
                    continue; // Value is not in config
                this._Statistics[sLabel] = dVal;
            }
            // Build chart data and theme colors
            var Data = [];
            var Colors = [];
            for (var i = 0; i < this._GroupByLabels.length; i++) {
                var sLabel = this._GroupByLabels[i];
                var dVal = this._Statistics[sLabel];
                var val = { y: dVal, stroke: "black", tooltip: sLabel + " = " + dVal };
                Data.push(val);
                Colors.push(this._Colors[sLabel]);
            }
            // Create theme and pie chart
            var myTheme = new SimpleTheme({ colors: Colors });
            var pieChart = new Chart(this._divChart);
            pieChart.setTheme(myTheme);
            pieChart.addPlot("default", {
                type: PiePlot,
                radius: 200,
                fontColor: "black",
                labelOffset: -20
            });
            pieChart.addSeries("Status", Data, undefined);
            var anim_h = new Highlight(pieChart, "default");
            var anim_t = new Tooltip(pieChart, "default");
            pieChart.render();
        };
        return WidgetHelper;
    })();
    return WidgetHelper;
});
//# sourceMappingURL=WidgetHelper.js.map